@@ -5,14 +5,14 @@
 #  joshua@mulliken.net to receive a copy
 import asyncio
 import logging
-import time
 from threading import Thread
-from typing import List, Callable, Tuple, Optional, Dict, Any
+from typing import List, Callable, Tuple, Optional
 
-from wyzeapy.const import PHONE_SYSTEM_TYPE, APP_VERSION, APP_VER, PHONE_ID, APP_NAME
-from wyzeapy.services.base_service import BaseService
-from wyzeapy.types import Device, PropertyIDs, DeviceTypes
-from wyzeapy.utils import check_for_errors_standard
+from aiohttp import ClientOSError, ContentTypeError
+
+from ..exceptions import UnknownApiError
+from .base_service import BaseService
+from ..types import Device, PropertyIDs, DeviceTypes
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -26,6 +26,9 @@ class SensorService(BaseService):
     _subscribers: List[Tuple[Sensor, Callable[[Sensor], None]]] = []
 
     async def update(self, sensor: Sensor) -> Sensor:
+        # Get updated device_params
+        async with BaseService._update_lock:
+            sensor.device_params = await self.get_updated_params(sensor.mac)
         properties = await self._get_device_info(sensor)
 
         for property in properties['data']['property_list']:
@@ -51,41 +54,27 @@ class SensorService(BaseService):
 
         self._subscribers.append((sensor, callback))
 
+    async def deregister_for_updates(self, sensor: Sensor):
+        self._subscribers = [(sense, callback) for sense, callback in self._subscribers if sense.mac != sensor.mac]
+
     def update_worker(self, loop):
         while True:
             for sensor, callback in self._subscribers:
                 _LOGGER.debug(f"Providing update for {sensor.nickname}")
-                callback(asyncio.run_coroutine_threadsafe(self.update(sensor), loop).result())
+                try:
+                    callback(asyncio.run_coroutine_threadsafe(self.update(sensor), loop).result())
+                except UnknownApiError as e:
+                    _LOGGER.warning(f"The update method detected an UnknownApiError: {e}")
+                except ClientOSError as e:
+                    _LOGGER.error(f"A network error was detected: {e}")
+                except ContentTypeError as e:
+                    _LOGGER.error(f"Server returned unexpected ContentType: {e}")
 
     async def get_sensors(self) -> List[Sensor]:
         if self._devices is None:
-            self._devices = await self.get_devices()
+            self._devices = await self.get_object_list()
 
         sensors = [Sensor(device.raw_dict) for device in self._devices if
                    device.type is DeviceTypes.MOTION_SENSOR or
                    device.type is DeviceTypes.CONTACT_SENSOR]
         return [Sensor(sensor.raw_dict) for sensor in sensors]
-
-    async def _get_device_info(self, device: Device) -> Dict[Any, Any]:
-        await self._auth_lib.refresh_if_should()
-
-        payload = {
-            "phone_system_type": PHONE_SYSTEM_TYPE,
-            "app_version": APP_VERSION,
-            "app_ver": APP_VER,
-            "device_mac": device.mac,
-            "sc": "9f275790cab94a72bd206c8876429f3c",
-            "ts": int(time.time()),
-            "device_model": device.product_model,
-            "sv": "c86fa16fc99d4d6580f82ef3b942e586",
-            "access_token": self._auth_lib.token.access_token,
-            "phone_id": PHONE_ID,
-            "app_name": APP_NAME
-        }
-
-        response_json = await self._auth_lib.post("https://api.wyzecam.com/app/v2/device/get_device_Info",
-                                                  json=payload)
-
-        check_for_errors_standard(response_json)
-
-        return response_json
